"""Command for managing bounces"""

import os
import poplib
import datetime

from django.conf import settings
from django.utils.translation import activate
from django.core.management.base import NoArgsCommand

from newsletter import models, dsnparser

def connect(account):
    conn = poplib.POP3(account.host)
    conn.user(account.user)
    conn.pass_(account.password)
    return conn

def persist_info(m):
    """Write info in the db

    :param m: the DSN Message instance
    """
    try:
        contact_status = models.ContactMailingStatus.objects.get(id=m.list_id)
        contact_status.status = 9
        contact_status.diagnostic_code = m.diagnostic_code,
        contact_status.rfc_status = m.status
        contact_status.save()
    except Exception, e:
        # TODO : decidere cosa fare se viene cancellata la riga da ContactMailingStatus.
        pass

    if m.update_contact:
        ## we're sure it works
        user = models.Contact.objects.get(email=m.original_recipient)
        user.valid = False
        user.save()

def save_message_for_diagnostic(msg_text, b):
    """Save the message for diagnostic purpose

    :param msg_text: the text message
    :param b: the BounceAccont
    """
    dirname = '/var/cache/newsletter/%s' % b.user
    if not os.path.exists(dirname):
        os.mkdir(dirname)

    f = open("%s/%s" % (dirname, datetime.datetime.now().strftime('%Y.%m.%d-%H:%M:%s')), 'w')
    f.write(msg_text)
    f.close()
             

def loop_on_messages(bounce_account, verbose=False):

    conn = connect(bounce_account)

    for msg in conn.list()[1]:
        n, dim = msg.split()
        if not dim:
            continue
        text_msg = "\n".join(conn.retr(n)[1])
        try:
            m = dsnparser.DSNParser(txt=text_msg)
            persist_info(m)
        except dsnparser.NotDSNError:
            print 'Message %s is not DSN' % n
            continue
        except:
            save_message_for_diagnostic(text_msg, bounce_account)
        if verbose:
            try:
                print repr(m)
            except:
                print "Messaggio non letto come dsn"
        conn.dele(n)
    conn.quit()

class Command(NoArgsCommand):
    """Loop on all bounce Accounts and parse all messages"""
    help = 'Loop on all bounce Accounts and parse all messages'

    def handle_noargs(self, **options):
        verbose = int(options['verbosity'])

        activate(settings.LANGUAGE_CODE)

        for b in models.BounceAccount.objects.all():
            if verbose:
                print b
            loop_on_messages(b, verbose)
