# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'BounceAccount'
        db.create_table('newsletter_bounceaccount', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=75)),
            ('host', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('user', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('password', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('port', self.gf('django.db.models.fields.IntegerField')(default=110)),
            ('tls', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
        ))
        db.send_create_signal('newsletter', ['BounceAccount'])

        # Adding model 'SMTPServer'
        db.create_table('newsletter_smtpserver', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('host', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('user', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('password', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('port', self.gf('django.db.models.fields.IntegerField')(default=25)),
            ('tls', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
            ('headers', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('mails_hour', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('newsletter', ['SMTPServer'])

        # Adding model 'Credit'
        db.create_table('newsletter_credit', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('smtp', self.gf('django.db.models.fields.related.ForeignKey')(related_name='credits', to=orm['newsletter.SMTPServer'])),
            ('dow_from', self.gf('django.db.models.fields.IntegerField')(max_length=1)),
            ('hour_from', self.gf('django.db.models.fields.TimeField')()),
            ('dow_to', self.gf('django.db.models.fields.IntegerField')(max_length=1)),
            ('hour_to', self.gf('django.db.models.fields.TimeField')()),
            ('mails_hour', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('newsletter', ['Credit'])

        # Adding unique constraint on 'Credit', fields ['smtp', 'dow_from', 'hour_from', 'dow_to', 'hour_to']
        db.create_unique('newsletter_credit', ['smtp_id', 'dow_from', 'hour_from', 'dow_to', 'hour_to'])

        # Adding model 'ContactExtraFields'
        db.create_table('newsletter_contactextrafields', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('contact', self.gf('django.db.models.fields.related.ForeignKey')(related_name='contact_extra_fields', to=orm['newsletter.Contact'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal('newsletter', ['ContactExtraFields'])

        # Adding model 'Contact'
        db.create_table('newsletter_contact', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('email', self.gf('django.db.models.fields.EmailField')(unique=True, max_length=75)),
            ('subscriber', self.gf('django.db.models.fields.BooleanField')(default=True, blank=True)),
            ('valid', self.gf('django.db.models.fields.BooleanField')(default=True, blank=True)),
            ('tester', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
            ('creation_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
            ('extra_fields', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='contacts', null=True, to=orm['newsletter.ContactExtraFields'])),
        ))
        db.send_create_signal('newsletter', ['Contact'])

        # Adding model 'MailingList'
        db.create_table('newsletter_mailinglist', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('creation_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
        ))
        db.send_create_signal('newsletter', ['MailingList'])

        # Adding M2M table for field unsubscribers on 'MailingList'
        db.create_table('newsletter_mailinglist_unsubscribers', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('mailinglist', models.ForeignKey(orm['newsletter.mailinglist'], null=False)),
            ('contact', models.ForeignKey(orm['newsletter.contact'], null=False))
        ))
        db.create_unique('newsletter_mailinglist_unsubscribers', ['mailinglist_id', 'contact_id'])

        # Adding model 'MailingListOrderedSubscribers'
        db.create_table('newsletter_mailinglistorderedsubscribers', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('mailing_list', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['newsletter.MailingList'])),
            ('subscriber', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['newsletter.Contact'])),
        ))
        db.send_create_signal('newsletter', ['MailingListOrderedSubscribers'])

        # Adding model 'Newsletter'
        db.create_table('newsletter_newsletter', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('content', self.gf('jumbo.db.fields.HTMLField')()),
            ('mailing_list', self.gf('django.db.models.fields.related.ForeignKey')(related_name='newsletter', to=orm['newsletter.MailingList'])),
            ('server', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['newsletter.SMTPServer'])),
            ('bouncer', self.gf('django.db.models.fields.related.ForeignKey')(related_name='newsletters', to=orm['newsletter.BounceAccount'])),
            ('header_sender', self.gf('django.db.models.fields.CharField')(default='Thunder Systems Newsletter<noreply@thundersystems.it>', max_length=255)),
            ('header_reply', self.gf('django.db.models.fields.CharField')(default='Thunder Systems Newsletter<noreply@thundersystems.it>', max_length=255)),
            ('status', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('sending_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now)),
            ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=50, db_index=True)),
            ('creation_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
        ))
        db.send_create_signal('newsletter', ['Newsletter'])

        # Adding M2M table for field test_contacts on 'Newsletter'
        db.create_table('newsletter_newsletter_test_contacts', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('newsletter', models.ForeignKey(orm['newsletter.newsletter'], null=False)),
            ('contact', models.ForeignKey(orm['newsletter.contact'], null=False))
        ))
        db.create_unique('newsletter_newsletter_test_contacts', ['newsletter_id', 'contact_id'])

        # Adding model 'Link'
        db.create_table('newsletter_link', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('url', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('creation_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal('newsletter', ['Link'])

        # Adding model 'Attachment'
        db.create_table('newsletter_attachment', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('newsletter', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['newsletter.Newsletter'])),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('file_attachment', self.gf('django.db.models.fields.files.FileField')(max_length=255)),
        ))
        db.send_create_signal('newsletter', ['Attachment'])

        # Adding model 'ContactMailingStatus'
        db.create_table('newsletter_contactmailingstatus', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('newsletter', self.gf('django.db.models.fields.related.ForeignKey')(related_name='mailing_status', to=orm['newsletter.Newsletter'])),
            ('contact', self.gf('django.db.models.fields.related.ForeignKey')(related_name='mailing_status', to=orm['newsletter.Contact'])),
            ('status', self.gf('django.db.models.fields.IntegerField')()),
            ('opened', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('opened_on_site', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('link_opened', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('unsubscription', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
            ('rfc_status', self.gf('django.db.models.fields.CharField')(max_length=10, null=True, blank=True)),
            ('diagnostic_code', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('creation_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('first_open_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('unsubscription_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
        ))
        db.send_create_signal('newsletter', ['ContactMailingStatus'])

        # Adding model 'LinkContactMailingStatus'
        db.create_table('newsletter_linkcontactmailingstatus', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('date_create', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('date_last_modify', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('contact_mailing_status', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['newsletter.ContactMailingStatus'])),
            ('link', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['newsletter.Link'])),
            ('click', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('newsletter', ['LinkContactMailingStatus'])

        # Adding model 'WorkGroup'
        db.create_table('newsletter_workgroup', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('group', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.Group'])),
        ))
        db.send_create_signal('newsletter', ['WorkGroup'])

        # Adding M2M table for field contacts on 'WorkGroup'
        db.create_table('newsletter_workgroup_contacts', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('workgroup', models.ForeignKey(orm['newsletter.workgroup'], null=False)),
            ('contact', models.ForeignKey(orm['newsletter.contact'], null=False))
        ))
        db.create_unique('newsletter_workgroup_contacts', ['workgroup_id', 'contact_id'])

        # Adding M2M table for field mailinglists on 'WorkGroup'
        db.create_table('newsletter_workgroup_mailinglists', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('workgroup', models.ForeignKey(orm['newsletter.workgroup'], null=False)),
            ('mailinglist', models.ForeignKey(orm['newsletter.mailinglist'], null=False))
        ))
        db.create_unique('newsletter_workgroup_mailinglists', ['workgroup_id', 'mailinglist_id'])

        # Adding M2M table for field newsletters on 'WorkGroup'
        db.create_table('newsletter_workgroup_newsletters', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('workgroup', models.ForeignKey(orm['newsletter.workgroup'], null=False)),
            ('newsletter', models.ForeignKey(orm['newsletter.newsletter'], null=False))
        ))
        db.create_unique('newsletter_workgroup_newsletters', ['workgroup_id', 'newsletter_id'])

        # Adding model 'Settings'
        db.create_table('newsletter_settings', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('date_create', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('date_last_modify', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('creator', self.gf('django.db.models.ForeignKey')(blank=True, related_name='newsletter_settings_creator', null=True, to=orm['auth.User'])),
            ('last_modifier', self.gf('django.db.models.ForeignKey')(blank=True, related_name='newsletter_settings_last_modifier', null=True, to=orm['auth.User'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=500, null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('type', self.gf('django.db.models.fields.CharField')(max_length=20)),
        ))
        db.send_create_signal('newsletter', ['Settings'])


    def backwards(self, orm):
        
        # Deleting model 'BounceAccount'
        db.delete_table('newsletter_bounceaccount')

        # Deleting model 'SMTPServer'
        db.delete_table('newsletter_smtpserver')

        # Deleting model 'Credit'
        db.delete_table('newsletter_credit')

        # Removing unique constraint on 'Credit', fields ['smtp', 'dow_from', 'hour_from', 'dow_to', 'hour_to']
        db.delete_unique('newsletter_credit', ['smtp_id', 'dow_from', 'hour_from', 'dow_to', 'hour_to'])

        # Deleting model 'ContactExtraFields'
        db.delete_table('newsletter_contactextrafields')

        # Deleting model 'Contact'
        db.delete_table('newsletter_contact')

        # Deleting model 'MailingList'
        db.delete_table('newsletter_mailinglist')

        # Removing M2M table for field unsubscribers on 'MailingList'
        db.delete_table('newsletter_mailinglist_unsubscribers')

        # Deleting model 'MailingListOrderedSubscribers'
        db.delete_table('newsletter_mailinglistorderedsubscribers')

        # Deleting model 'Newsletter'
        db.delete_table('newsletter_newsletter')

        # Removing M2M table for field test_contacts on 'Newsletter'
        db.delete_table('newsletter_newsletter_test_contacts')

        # Deleting model 'Link'
        db.delete_table('newsletter_link')

        # Deleting model 'Attachment'
        db.delete_table('newsletter_attachment')

        # Deleting model 'ContactMailingStatus'
        db.delete_table('newsletter_contactmailingstatus')

        # Deleting model 'LinkContactMailingStatus'
        db.delete_table('newsletter_linkcontactmailingstatus')

        # Deleting model 'WorkGroup'
        db.delete_table('newsletter_workgroup')

        # Removing M2M table for field contacts on 'WorkGroup'
        db.delete_table('newsletter_workgroup_contacts')

        # Removing M2M table for field mailinglists on 'WorkGroup'
        db.delete_table('newsletter_workgroup_mailinglists')

        # Removing M2M table for field newsletters on 'WorkGroup'
        db.delete_table('newsletter_workgroup_newsletters')

        # Deleting model 'Settings'
        db.delete_table('newsletter_settings')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'newsletter.attachment': {
            'Meta': {'object_name': 'Attachment'},
            'file_attachment': ('django.db.models.fields.files.FileField', [], {'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'newsletter': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['newsletter.Newsletter']"}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'newsletter.bounceaccount': {
            'Meta': {'object_name': 'BounceAccount'},
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'host': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'}),
            'port': ('django.db.models.fields.IntegerField', [], {'default': '110'}),
            'tls': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'user': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'})
        },
        'newsletter.contact': {
            'Meta': {'object_name': 'Contact'},
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'unique': 'True', 'max_length': '75'}),
            'extra_fields': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'contacts'", 'null': 'True', 'to': "orm['newsletter.ContactExtraFields']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'subscriber': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'tester': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'valid': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'})
        },
        'newsletter.contactextrafields': {
            'Meta': {'object_name': 'ContactExtraFields'},
            'contact': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'contact_extra_fields'", 'to': "orm['newsletter.Contact']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'newsletter.contactmailingstatus': {
            'Meta': {'object_name': 'ContactMailingStatus'},
            'contact': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'mailing_status'", 'to': "orm['newsletter.Contact']"}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'diagnostic_code': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'first_open_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'link': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'mailing_status'", 'to': "orm['newsletter.Link']", 'through': "orm['newsletter.LinkContactMailingStatus']", 'blank': 'True', 'symmetrical': 'False', 'null': 'True'}),
            'link_opened': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'newsletter': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'mailing_status'", 'to': "orm['newsletter.Newsletter']"}),
            'opened': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'opened_on_site': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'rfc_status': ('django.db.models.fields.CharField', [], {'max_length': '10', 'null': 'True', 'blank': 'True'}),
            'status': ('django.db.models.fields.IntegerField', [], {}),
            'unsubscription': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'unsubscription_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'})
        },
        'newsletter.credit': {
            'Meta': {'unique_together': "(('smtp', 'dow_from', 'hour_from', 'dow_to', 'hour_to'),)", 'object_name': 'Credit'},
            'dow_from': ('django.db.models.fields.IntegerField', [], {'max_length': '1'}),
            'dow_to': ('django.db.models.fields.IntegerField', [], {'max_length': '1'}),
            'hour_from': ('django.db.models.fields.TimeField', [], {}),
            'hour_to': ('django.db.models.fields.TimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mails_hour': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'smtp': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'credits'", 'to': "orm['newsletter.SMTPServer']"})
        },
        'newsletter.link': {
            'Meta': {'object_name': 'Link'},
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'newsletter.linkcontactmailingstatus': {
            'Meta': {'object_name': 'LinkContactMailingStatus'},
            'click': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'contact_mailing_status': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['newsletter.ContactMailingStatus']"}),
            'date_create': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'date_last_modify': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'link': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['newsletter.Link']"})
        },
        'newsletter.mailinglist': {
            'Meta': {'object_name': 'MailingList'},
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'subscribers': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'mailinglist_subscriber'", 'symmetrical': 'False', 'through': "orm['newsletter.MailingListOrderedSubscribers']", 'to': "orm['newsletter.Contact']"}),
            'unsubscribers': ('django.db.models.fields.related.ManyToManyField', [], {'blank': 'True', 'related_name': "'mailinglist_unsubscriber'", 'null': 'True', 'symmetrical': 'False', 'to': "orm['newsletter.Contact']"})
        },
        'newsletter.mailinglistorderedsubscribers': {
            'Meta': {'object_name': 'MailingListOrderedSubscribers'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mailing_list': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['newsletter.MailingList']"}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'subscriber': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['newsletter.Contact']"})
        },
        'newsletter.newsletter': {
            'Meta': {'object_name': 'Newsletter'},
            'bouncer': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'newsletters'", 'to': "orm['newsletter.BounceAccount']"}),
            'content': ('jumbo.db.fields.HTMLField', [], {}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'header_reply': ('django.db.models.fields.CharField', [], {'default': "'Thunder Systems Newsletter<noreply@thundersystems.it>'", 'max_length': '255'}),
            'header_sender': ('django.db.models.fields.CharField', [], {'default': "'Thunder Systems Newsletter<noreply@thundersystems.it>'", 'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mailing_list': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'newsletter'", 'to': "orm['newsletter.MailingList']"}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'sending_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'server': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['newsletter.SMTPServer']"}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50', 'db_index': 'True'}),
            'status': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'test_contacts': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['newsletter.Contact']", 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'newsletter.settings': {
            'Meta': {'object_name': 'Settings'},
            'creator': ('django.db.models.ForeignKey', [], {'blank': 'True', 'related_name': "'newsletter_settings_creator'", 'null': 'True', 'to': "orm['auth.User']"}),
            'date_create': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'date_last_modify': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_modifier': ('django.db.models.ForeignKey', [], {'blank': 'True', 'related_name': "'newsletter_settings_last_modifier'", 'null': 'True', 'to': "orm['auth.User']"}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'type': ('django.db.models.fields.CharField', [], {'max_length': '20'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '500', 'null': 'True', 'blank': 'True'})
        },
        'newsletter.smtpserver': {
            'Meta': {'object_name': 'SMTPServer'},
            'headers': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'host': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mails_hour': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'}),
            'port': ('django.db.models.fields.IntegerField', [], {'default': '25'}),
            'tls': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'user': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'})
        },
        'newsletter.workgroup': {
            'Meta': {'object_name': 'WorkGroup'},
            'contacts': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['newsletter.Contact']", 'null': 'True', 'blank': 'True'}),
            'group': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.Group']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mailinglists': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['newsletter.MailingList']", 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'newsletters': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['newsletter.Newsletter']", 'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['newsletter']
