"""Utils for importation of contacts"""
import csv
from datetime import datetime
from django.db import connection

import xlrd
import vobject

from django.core.validators import validate_email
from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import smart_unicode

#from tagging.models import Tag

from newsletter.models import Contact
from newsletter.models import MailingList


COLUMNS = ['email', 'first_name', 'last_name', 'tags']
csv.register_dialect('edn', delimiter=';')


def create_contact(contact, workgroups=[]):
    """Create a contact and validate the mail"""
    email = contact[0]
    extra_fields= contact[1]

    contact, created = Contact.objects.get_or_create(
        email=email
    )

    #if not created:
    #    new_tags = contact_dict.get('tags')
    #    if new_tags:
    #        Tag.objects.update_tags(contact, '%s, %s' % (contact.tags, new_tags))

    for workgroup in workgroups:
        workgroup.contacts.add(contact)

    return contact, created


def create_contacts(contact_list, importer_name, workgroups=[]):
    """Create all the contacts to import and
    associated them in a mailing list"""
    print "Creo Mailing List"
    inserted = 0
    when = str(datetime.now()).split('.')[0]
    mailing_list = MailingList(
        name=_('Mailing list created by importation at %s') % when,
        description=_('Contacts imported by %s.') % importer_name)
    mailing_list.save()

    cursor = connection.cursor()
    for i, contact in enumerate(contact_list):
        #if i % 1000 == 0:
        #    print "Sono a %s" % i
        #sql = """INSERT INTO newsletter_mailinglist_subscribers (mailinglist_id, contact_id)
        mailing_list.add_subscriber(contact[0], extra_fields=contact[1])
        inserted += 1

    return inserted


def vcard_contacts_import(stream, workgroups=[]):
    contacts = []
    vcards = vobject.readComponents(stream)

    for vcard in vcards:
        contact = {'email': vcard.email.value,
                   'first_name': vcard.n.value.given,
                   'last_name': vcard.n.value.family}
        contacts.append(contact)

    return create_contacts(contacts, 'vcard', workgroups)


def text_contacts_import(stream, workgroups=[], verbose=False):
    """Import contact from a plaintext file, like CSV"""
    contacts = []
    contact_reader = csv.reader(stream, dialect='edn')

    # EMAIL MUST BE THE FIRST COLUMN
    map_column = {'email':0}

    for i, row in enumerate(contact_reader):
        if i % 1000 == 0:
            if verbose: print "Sono a %s" % i

        if i == 0:
            for i in range(1, 100):
                try:
                    map_column[i] = row[i]
                except IndexError, e:
                    break
            continue

        if not row: continue

        email = smart_unicode(row[0], encoding='latin1')
        email = unicode(email).strip().lower()

        if not email:
            if verbose: print email
            continue

        try:
            validate_email(email)
        except ValidationError, e:
            if verbose: print "Email non valida : %s" % email
            continue

        extra_fields = {}
        for i in range(1, len(map_column.keys())):
            try:
                value = smart_unicode(row[i], encoding='latin1')
                value = unicode(value).strip().lower()
                extra_fields[map_column[i]] = value
            except IndexError, e:
                if verbose: print "Errore : %s" % e
                break

        #print "."
        contacts.append((email, extra_fields))
    return create_contacts(contacts, 'text', workgroups)


def excel_contacts_import(stream, workgroups=[]):
    contacts = []
    wb = xlrd.open_workbook(file_contents=stream.read())
    sh = wb.sheet_by_index(0)

    # EMAIL MUST BE THE FIRST COLUMN
    map_column = {'email':0}

    for row in range(sh.nrows):
        if row == 0:
            for i in range(1, 100):
                try:
                    value = sh.cell(row, i).value
                    map_column[i] = value
                except IndexError, e:
                    print e
                    break
            continue

        email = smart_unicode(sh.cell(row, 0).value, encoding='latin1')
        email = unicode(email).strip().lower()

        if not email:
            continue

        try:
            validate_email(email)
        except ValidationError, e:
            #print e
            continue

        extra_fields = {}
        for i in range(1, len(map_column.keys())):
            try:
                value = smart_unicode(sh.cell(row, i).value, encoding='latin1')
                value = unicode(value).strip().lower()
                extra_fields[map_column[i]] = value
            except IndexError, e:
                #print e
                break

        #print "."
        contacts.append((email, extra_fields))
    return create_contacts(contacts, 'excel', workgroups)


def import_dispatcher(source, type_, workgroups):
    """Select importer and import contacts"""
    if type_ == 'vcard':
        return vcard_contacts_import(source, workgroups)
    elif type_ == 'text':
        return text_contacts_import(source, workgroups)
    elif type_ == 'excel':
        return excel_contacts_import(source, workgroups)
    return 0
