#! -*- coding: utf-8 -*-

import csv, sys
from datetime import timedelta, datetime, date
import base64
from urllib import urlencode
from urlparse import urlparse
from urlparse import urlunparse
# For Python < 2.6
try:
    from urlparse import parse_qs
except ImportError:
    from cgi import parse_qs

from django.template import RequestContext
from django.shortcuts import get_object_or_404
from django.shortcuts import render_to_response
from django.contrib.sites.models import Site
from django.contrib.auth.decorators import login_required
from django.template.loader import render_to_string as render_file
from django.db.models import Q
from django.http import HttpResponse, Http404
from django.http import HttpResponseRedirect
from django.utils.encoding import smart_str
from django.utils.translation import ugettext as _
from django.template.defaultfilters import date
from django.utils.encoding import smart_str

from newsletter.models import Newsletter, LinkContactMailingStatus
from newsletter.models import MailingList
from newsletter.models import ContactMailingStatus
from newsletter.models import Link
from newsletter.models import SMTPServer, Credit
from newsletter.utils import render_string
from newsletter.utils.nl_utils import body_insertion
from newsletter.utils.nl_utils import track_links
from newsletter.utils.tokens import untokenize
from newsletter.utils.ofc import Chart
from newsletter.settings import TRACKING_LINKS, INCLUDE_UNSUBSCRIPTION
from newsletter.settings import USE_UTM_TAGS
from newsletter.settings import TRACKING_IMAGE
from newsletter.utils.statistics import get_newsletter_top_links
from newsletter.utils.statistics import get_newsletter_statistics
from newsletter.utils.statistics import get_newsletter_opening_statistics
from newsletter.utils.statistics import get_newsletter_clicked_link_statistics
from newsletter.forms import CreditForm

# SMTP SERVER
#def set_credits(request, smtp_id):
#    """Set number of mails per hour"""
#    try:
#        smtp = SMTPServer.objects.get(id=smtp_id)
#    except:
#        raise Http404
#
#    hours = range(0,24)
#    if request.method == 'POST':
#        form = CreditForm(smtp, request.POST)
#        if form.is_valid():
#            for day in range(0,7):
#                for hour in hours:
#                    try:
#                        credit = smtp.credit_set.get(day_of_week=day, hour=hour)
#                    except:
#                        credit = Credit()
#                        credit.smtp = smtp
#                        credit.day_of_week = day
#                        credit.hour = hour
#                    credit.mails_hour = form.cleaned_data["credit_%s_%s" % (day, hour)]
#                    credit.save()
#    else:
#        form = CreditForm(smtp)
#    return render_to_response(
#        "newsletter/smtpserver_set_credits.html",
#        {"form":form, "hours":hours},
#        context_instance=RequestContext(request)
#    )

# MAILINGLIST
def view_mailinglist_unsubscribe(request, slug, uidb36, token):
    """Unsubscribe a contact to a mailing list"""
    newsletter = get_object_or_404(Newsletter, slug=slug)
    contact = untokenize(uidb36, token)

    already_unsubscribed = contact in newsletter.mailing_list.unsubscribers.all()

    if request.POST.get('email') and not already_unsubscribed:
        newsletter.mailing_list.unsubscribers.add(contact)
        newsletter.mailing_list.save()
        already_unsubscribed = True

        try:
            cms = ContactMailingStatus.objects.filter(
                newsletter=newsletter,
                contact=contact,
                status=0
            ).order_by('-id')
            if cms:
                cms = cms[0]
            cms.unsubscription = True
            if not cms.unsubscription_date:
                cms.unsubscription_date = datetime.now()
            cms.save()
        except:
            raise Http404

    return render_to_response(
        'newsletter/mailing_list_unsubscribe.html',
        {'email': contact.email, 'already_unsubscribed': already_unsubscribed},
        context_instance=RequestContext(request)
    )

def view_mailinglist_subscribe(request, form_class, mailing_list_id=None):
    """
    A simple view that shows a form for subscription
    for a mailing list(s).
    """
    subscribed = False
    mailing_list = None
    if mailing_list_id:
        mailing_list = get_object_or_404(MailingList, id=mailing_list_id)

    if request.POST and not subscribed:
        form = form_class(request.POST)
        if form.is_valid():
            form.save(mailing_list)
            subscribed = True
    else:
        form = form_class()

    return render_to_response(
        'newsletter/mailing_list_subscribe.html',
        {'subscribed': subscribed, 'mailing_list': mailing_list, 'form': form},
        context_instance=RequestContext(request)
    )

# NEWSLETTER
def render_newsletter(request, slug, context):
    """Return a newsletter in HTML format"""
    newsletter = get_object_or_404(Newsletter, slug=slug)
    context.update({
        'newsletter': newsletter,
        'domain': Site.objects.get_current().domain
    })

    content = render_string(newsletter.content, context)
    title = render_string(newsletter.title, context)
    if TRACKING_LINKS:
        content = track_links(content, context)

    if INCLUDE_UNSUBSCRIPTION:
        unsubscription = render_file(
            'newsletter/newsletter_link_unsubscribe.html', context
        )
        content = body_insertion(content, unsubscription, end=True)

    return render_to_response(
        'newsletter/newsletter_detail.html',
        {'content': content, 'title': title, 'object': newsletter},
        context_instance=RequestContext(request)
    )

@login_required
def view_newsletter_preview(request, slug):
    """View of the newsletter preview"""
    context = {'contact': request.user}
    return render_newsletter(request, slug, context)

def view_newsletter_contact(request, slug, uidb36, token):
    """Visualization of a newsletter by an user"""
    newsletter = get_object_or_404(Newsletter, slug=slug)
    contact = untokenize(uidb36, token)
    try:
        cms = ContactMailingStatus.objects.filter(
            newsletter=newsletter,
            contact=contact,
            status=0
            ).order_by('-id')
        if cms:
            cms = cms[0]
        cms.opened_on_site = cms.opened_on_site + 1
        if not cms.first_open_date:
            cms.first_open_date = datetime.now()
        cms.save()
    except:
        raise Http404

    context = {
        'contact': contact, 'uidb36': uidb36, 'token': token
    }

    return render_newsletter(request, slug, context)

# STATISTICS
BG_COLOR = '#ffffff'
GRID_COLOR = '#eeeeee'
AXIS_COLOR = '#666666'
BAR_COLOR_1 = '#5b80b2'
BAR_COLOR_2 = '#ff3333'
BAR_COLOR_3 = '#9459b4'
BAR_COLOR_4 = '#5eca71'

def get_statistics_period(newsletter):
    status = ContactMailingStatus.objects.filter(
        Q(opened__gt=0) |
        Q(opened_on_site__gt=0) |
        Q(link_opened__gt=0),
        newsletter=newsletter
    )
    if not status:
        return []
    start_date = newsletter.sending_date.date()
    end_date = status.latest('creation_date').creation_date.date()

    period = []
    for i in range((end_date - start_date).days + 1):
        period.append(start_date + timedelta(days=i))
    return period

@login_required
def view_newsletter_statistics(request, slug):
    """Display the statistics of a newsletters"""
    opts = Newsletter._meta
    newsletter = get_object_or_404(Newsletter, slug=slug)

    context = {
        'title': _('Statistics of %s') % newsletter.__unicode__(),
        'object': newsletter,
        'opts': opts,
        'app_label': opts.app_label,
        'stats': newsletter.get_totals(),
        'top_links': newsletter.get_newsletter_top_links(),
        'period': get_statistics_period(newsletter)
    }

    return render_to_response(
        'newsletter/newsletter_statistics.html',
        context, context_instance=RequestContext(request)
    )

@login_required
def view_newsletter_report(request, slug):
    newsletter = get_object_or_404(Newsletter, slug=slug)
    status = ContactMailingStatus.objects.filter(
        newsletter=newsletter,
        creation_date__gte=newsletter.sending_date
    )
    links = set([s.link for s in status.exclude(link=None)])

    def header_line(links):
        link_cols = [smart_str(link.title) for link in links]
#        return [smart_str(_('first name')), smart_str(_('last name')),
#                smart_str(_('email')), smart_str(_('openings'))] + link_cols
        return [smart_str(_('email')), smart_str(_('openings'))] + link_cols

    def contact_line(contact, links):
        contact_status = status.filter(contact=contact)

        link_cols = [contact_status.filter(
            opened__gt=0,
            link=link).count() for link in links]
        openings = contact_status.filter(
            Q(opened__gt=0) |
            Q(opened_on_site__gt=0)
        ).count()
#        return [smart_str(contact.first_name), smart_str(contact.last_name),
#                smart_str(contact.email), openings] + link_cols
        return [smart_str(contact.email), openings] + link_cols

    response = HttpResponse(mimetype='text/csv')
    response['Content-Disposition'] = 'attachment; filename=report-%s.csv' % newsletter.slug

    writer = csv.writer(response)
    writer.writerow(header_line(links))
    for contact in newsletter.mailing_list.expedition_set():
        writer.writerow(contact_line(contact, links))

    return response

@login_required
def view_newsletter_density(request, slug):
    newsletter = get_object_or_404(Newsletter, slug=slug)
    context = {
        'object': newsletter,
        
    }

    return render_to_response(
        'newsletter/newsletter_density.html',
        context, context_instance=RequestContext(request)
    )

@login_required
def view_newsletter_charts(request, slug, template_name="newsletter/newsletter_charts.html"):
    from jumbo.utils.charts import Chart, Property, SubProperty

    newsletter = get_object_or_404(Newsletter, slug=slug)
    start = request.POST.get('start')
    start = start.encode()
    start = datetime.strptime(start, "%Y-%m-%d").date()
    end = request.POST.get('end')
    end = end.encode()
    end = datetime.strptime(end, "%Y-%m-%d").date()

    label = []
    mailsTotal=[]
    mailsSent=[]
    mailsError=[]
    mailsInvalid=[]
    mailsBounced=[]
    mailsOpenedClient=[]
    mailsOpenedSite=[]
    mailsLinkOpened=[]
    mailsTotOpened=[]
    mailsTotNotOpened=[]

    # prendo i dati di ogni giorno
    totals = newsletter.get_totals(start, end)
    #print totals
    for total in totals:
        label.append('%s' % total['date_c'])

        """
        mails
        sent
        error
        invalid
        bounced
        opened_on_client
        opened_on_site
        link_opened
        tot_opened
        tot_not_opened
        """
        try:
            mailsTotal.append(int(total['mails']) or 0)
            mailsSent.append(int(total['sent']) or 0)
            mailsError.append(int(total['error']) or 0)
            mailsInvalid.append(int(total['invalid']) or 0)
            mailsBounced.append(int(total['bounced']) or 0)
            mailsOpenedClient.append(int(total['opened_on_client']) or 0)
            mailsOpenedSite.append(int(total['opened_on_site']) or 0)
            mailsLinkOpened.append(int(total['link_open']) or 0)
            mailsTotOpened.append(int(total['tot_opened']) or 0)
            mailsTotNotOpened.append(int(total['tot_not_opened']) or 0)
        except:
            None        

    title = str(newsletter.title)
    subtitle = str(_("Statistics"))
    yAxis = str(_("Quantita"))

    line_chart = Chart('graph1', defaultSeriesType='line')
#    line_chart.add_property('title', text=title)
    line_chart.add_property('subtitle', text=subtitle)
    line_chart.add_property('xAxis', categories=label)
    line_chart.add_property('yAxis', title=SubProperty(text=yAxis))
    line_chart.add_property('tooltip', crosshairs=True, shared=True)
    line_chart.add_property(
        'legend',
        layout='vertical', align='right',
        verticalAlign='top', x=-10, y=5, borderWidth=1
    )

    line_chart.add_series(name="Mails Total", data=mailsTotal)
    line_chart.add_series(name="Mails Sent", data=mailsSent)
    line_chart.add_series(name="Mails in Error", data=mailsError)
    line_chart.add_series(name="Invalid Mails", data=mailsInvalid)
    line_chart.add_series(name="Bounced Mails", data=mailsBounced)
    line_chart.add_series(name="Opened Mails on Client", data=mailsOpenedClient)
    line_chart.add_series(name="Opened Mails on Site", data=mailsOpenedSite)
    line_chart.add_series(name="Opened Links", data=mailsLinkOpened)
    line_chart.add_series(name="Total Opened", data=mailsTotOpened)
    line_chart.add_series(name="Total not Opened", data=mailsTotNotOpened)
    

    context = {
        'line_chart': line_chart,
#        'object': newsletter,
    }

    return render_to_response(
        template_name,
        context, context_instance=RequestContext(request)
    )

# TRACKING
def view_newsletter_tracking(request, slug, uidb36, token):
    """Track the opening of the newsletter by requesting a blank img"""
    newsletter = get_object_or_404(Newsletter, slug=slug)
    contact = untokenize(uidb36, token)
    try:
        cms = ContactMailingStatus.objects.filter(
            newsletter=newsletter,
            contact=contact,
            status=0
        ).order_by('-id')
        if cms:
            cms = cms[0]
        cms.opened = cms.opened + 1
        if not cms.first_open_date:
            cms.first_open_date = datetime.now()
        cms.save()
    except:
        raise Http404
    return HttpResponse(base64.b64decode(TRACKING_IMAGE), mimetype='image/png')

def view_newsletter_tracking_link(request, slug, uidb36, token, link_id):
    """Track the opening of a link on the website"""
    newsletter = get_object_or_404(Newsletter, slug=slug)
    contact = untokenize(uidb36, token)
    link = get_object_or_404(Link, pk=link_id)
    print >> sys.stderr, "newsletter: %s" % newsletter
    print >> sys.stderr, "contact: %s" % contact
    print >> sys.stderr, "link: %s" % link

    try:
        cms = ContactMailingStatus.objects.filter(
            newsletter=newsletter,
            contact=contact,
            status=0
        ).order_by('-id')
        if cms:
            cms = cms[0]
        cms.link_opened = cms.link_opened + 1
        if cms.opened == 0 and cms.opened_on_site == 0:
            cms.opened = cms.opened + 1
        cms.save()
        try:
            link_ms = LinkContactMailingStatus.objects.get(contact_mailing_status=cms,
                                                           link = link)
        except LinkContactMailingStatus.DoesNotExist:
            link_ms = LinkContactMailingStatus(contact_mailing_status=cms,
                                               link = link)
        link_ms.click = link_ms.click + 1
        link_ms.save()
    except Exception:
        raise Http404

    if not USE_UTM_TAGS:
        return HttpResponseRedirect(link.url)

    url_parts = urlparse(link.url)
    query_dict = parse_qs(url_parts.query)
    query_dict.update({
        'utm_source': 'newsletter_%s' % newsletter.pk,
        'utm_medium': 'mail',
        'utm_campaign': smart_str(newsletter.title)
    })
    url = urlunparse((
        url_parts.scheme, url_parts.netloc, url_parts.path,
        url_parts.params, urlencode(query_dict), url_parts.fragment
    ))
    return HttpResponseRedirect(url)
